# == Class: emacs
#
# Puppet module to install, deploy and configure emacs.
#
class emacs (
  $package            = true,
  $emacs_package_name = $emacs::params::emacs_package_name,
  $emacs_config       = $emacs::params::emacs_config
) inherits emacs::params {
  case $package {
    true    : { $ensure_package = 'present' }
    false   : { $ensure_package = 'purged' }
    latest  : { $ensure_package = 'latest' }
    default : { fail('package must be true, false or lastest') }
  }

  package { $emacs_package_name:
    ensure => $ensure_package,
  }

  file { $emacs_config:
    ensure  => present,
    backup  => true,
    path    => $emacs_config,
    owner   => 'root',
    group   => 'root',
    mode    => '0600',
    content => template('emacs/emacs.erb'),
    require => Package[$emacs_package_name],
  }
}
# EOF
